import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

// 用户模式
const USER_LEVEL = {
  USER_VISITOR: 'USER_VISITOR',
  USER_LOGIN: 'USER_LOGIN'
}

// 游客模式 路由集合
const USER_VISITOR_ROUTES = [
  {
    path: '/login',
    name: 'login',
    redirect: '/login/index',
    component: Layout,
    meta: {
      title: '登录',
      USER_LEVEL: USER_LEVEL.USER_VISITOR
    },
    children: [
      {
        path: '/login/index',
        name: 'loginIndex',
        meta: { showFooter: true, showHeader: false, title: '登录', USER_LEVEL: USER_LEVEL.USER_VISITOR },
        component: () => import('@/views/login/login')
      }
    ]
  },
  // {
  //   path: '/searchCenter',
  //   name: 'searchCenter',
  //   redirect: '/searchCenter/index',
  //   component: Layout,
  //   meta: { title: '搜索', USER_LEVEL: USER_LEVEL.USER_VISITOR },
  //   children: [
  //     {
  //       path: '/searchCenter/index',
  //       name: 'searchCenterIndex',
  //       meta: { title: '搜索', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false },
  //       component: () => import('@/views/searchCenter/index')
  //     }
  //   ]
  // },
  {
    path: '/',
    redirect: '/homePage/index',
    name: 'index',
    component: Layout,
    meta: {
      title: '首页',
      USER_LEVEL: USER_LEVEL.USER_VISITOR
    },
    children: [
      {
        path: '/homePage/index',
        name: 'homePage',
        meta: {
          showFooter: true,
          title: '首页',
          USER_LEVEL: USER_LEVEL.USER_VISITOR,
          showHeader: false,
          animation: false
        },
        component: () => import('@/views/homePage/index')
      },
      {
        path: '/news/index',
        name: 'news',
        meta: { title: '新闻咨询', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
        component: () => import('@/views/news/index')
      },
      {
        path: '/newsDetails/index',
        name: 'newsDetails',
        meta: { title: '新闻详情', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
        component: () => import('@/views/news/details.vue')
      },
      {
        path: '/Feedback/index',
        name: 'Feedback',
        meta: { title: '意见反馈', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
        component: () => import('@/views/Feedback/index')
      },
      {
        path: '/learningPlatform/index',
        name: 'learningPlatform',
        meta: { title: '学习平台', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
        component: () => import('@/views/learningPlatform/index')
      },
      {
        path: '/courseResources/index',
        name: 'courseResources',
        meta: { title: '课程资源', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
        component: () => import('@/views/courseResources/index')
      },
      {
        path: '/assessmentRating/index',
        name: 'assessmentRating',
        meta: { title: '考核评级', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
        component: () => import('@/views/assessmentRating/index')
      },
      {
        path: '/collaborationCases/index',
        name: 'collaborationCases',
        meta: { title: '合作案例', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
        component: () => import('@/views/collaborationCases/index')
      },
      {
        path: '/aboutUs/index',
        name: 'aboutUs',
        meta: { title: '关于我们', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
        component: () => import('@/views/aboutUs/index')
      },
      {
        path: '/learningCenter',
        name: 'learningCenter',
        meta: { title: '学习中心', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
        component: () => import('@/views/learningCenter/index'),
        children:[
          {
            path: 'index',
            name: 'learningCenter',
            component: () => import('@/views/learningCenter/index'),
          },
          {
            path: 'purchased',
            name: 'purchased',
            meta: { title: '已购课程',activeMenu:'purchased', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
            component: () => import('@/views/learningCenter/children/purchased')
          },
          {
            path: 'role',
            name: 'role',
            meta: { title: '角色管理',activeMenu:'role', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
            component: () => import('@/views/learningCenter/children/role')
          },
          {
            path: 'group',
            name: 'group',
            meta: { title: "小组管理",activeMenu:'group', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
            component: () => import('@/views/learningCenter/children/group')
          },
          {
            path: 'participants',
            name: 'participants',
            meta: { title: "学员管理",activeMenu:'participants', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
            component: () => import('@/views/learningCenter/children/participants')
          },
          {
            path: 'statistics',
            name: 'statistics',
            meta: { title: "数据统计",activeMenu:'statistics', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
            component: () => import('@/views/learningCenter/children/statistics')
          },
          {
            path: 'my',
            name: 'my',
            meta: { title: "我的课程",activeMenu:'my', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
            component: () => import('@/views/learningCenter/children/my')
          },
          {
            path: 'myGroup',
            name: 'myGroup',
            meta: { title: "我的小组",activeMenu:'myGroup', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
            component: () => import('@/views/learningCenter/children/myGroup')
          },
          {
            path: 'statistics',
            name: 'statistics',
            meta: { title: "数据统计",activeMenu:'statistics', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
            component: () => import('@/views/learningCenter/children/statistics')
          },
          {
            path: 'statistics',
            name: 'statistics',
            meta: { title: "数据统计",activeMenu:'statistics', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
            component: () => import('@/views/learningCenter/children/statistics')
          },
          {
            path: 'statistics',
            name: 'statistics',
            meta: { title: "数据统计",activeMenu:'statistics', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
            component: () => import('@/views/learningCenter/children/statistics')
          }
        ]
      },
      {
        path: '/pdf',
        name: 'learningCenter',
        meta: { title: '视频pdfdemo', USER_LEVEL: USER_LEVEL.USER_VISITOR, showHeader: false, animation: false },
        component: () => import('@/views/learningCenter/index')
      },

    ]
  }
]
// 其他路由集合
const OTHER_ROUTES = [
  { path: '/404', hidden: true, component: () => import('@/views/404'), meta: { USER_LEVEL: USER_LEVEL.USER_VISITOR }},
  { path: '*', redirect: '/404' }
]

export default USER_VISITOR_ROUTES.concat(OTHER_ROUTES)
